@@ -4,7 +4,7 @@ use strict;
 use warnings FATAL => 'all';
 
 use version;
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Prancer::Plugin;
 use parent qw(Prancer::Plugin Exporter);
@@ -35,7 +35,7 @@ sub load {
 
     my $self = bless({}, $class);
 
-    my $config = $self->config->get("database");
+    my $config = ($self->config() && $self->config->get("database")) || {};
     unless (defined($config) && ref($config) && ref($config) eq "HASH") {
         croak "could not initialize database connection: no configuration found";
     }
@@ -128,6 +128,11 @@ file:
                 autocommit: true
                 charset: utf8
                 connection_check_threshold: 10
+                dsn_extra:
+                    RaiseError: 0
+                    PrintError: 1
+                on_connect:
+                    - SET search_path=public
 
 The "connection-name" can be anything you want it to be. This will be used when
 requesting a connection from the plugin to determine which connection to return.
@@ -190,6 +195,21 @@ still exists and will reconnect if one does not. This handles cases where the
 database handle hasn't been used in a while and the underlying connection has
 gone away. If this is not set then it will default to 30 seconds.
 
+=item dsn_extra
+
+If you have any further connection parameters that need to be appended to the
+dsn then you can put them in the configuration as a hash. This hash will be
+merged into the default parameters and overwrite any that are duplicated. The
+dsn parameters set by default are C<AutoCommit> to 1, C<RaiseError> to 1, and
+C<PrintError> to 0. This option will take precedence over the C<autocommit>
+flag above.
+
+=item on_connect
+
+This can be an array of commands execute on a successful connection. These will
+be executed on every connection so if the connection goes away but is re-
+established then these commands will be run again.
+
 =back
 
 =head1 CREDIT
