@@ -4,7 +4,7 @@ use strict;
 use warnings FATAL => 'all';
 
 use version;
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Try::Tiny;
 use Carp;
@@ -37,6 +37,8 @@ sub new {
     $self->{'_autocommit'}      = $config->{'autocommit'};
     $self->{'_charset'}         = $config->{'charset'};
     $self->{'_check_threshold'} = $config->{'connection_check_threshold'} || 30;
+    $self->{'_dsn_extra'}       = $config->{'dsn_extra'} || {};
+    $self->{'_on_connect'}      = $config->{'on_connect'} || [];
 
     # store a pool of database connection handles
     $self->{'_handles'} = {};
@@ -98,6 +100,9 @@ sub _get_connection {
     my $dbh = undef;
     try {
         $dbh = DBI->connect(@{$self->{'_dsn'}}) || croak "${\$DBI::errstr}\n";
+
+        # run any on_connect sql
+        $dbh->do($_) for (@{$self->{'_on_connect'}});
     } catch {
         my $error = (defined($_) ? $_ : "unknown");
         croak "could not initialize database connection '${\$self->{'_connection'}}': ${error}";
@@ -131,4 +136,28 @@ sub _check_connection {
     return 0;
 }
 
+# stolen from Hash::Merge::Simple
+## no critic (ProhibitUnusedPrivateSubroutines)
+sub _merge {
+    my ($self, $left, @right) = @_;
+
+    return $left unless @right;
+    return $self->_merge($left, $self->_merge(@right)) if @right > 1;
+
+    my ($right) = @right;
+    my %merged = %{$left};
+
+    for my $key (keys %{$right}) {
+        my ($hr, $hl) = map { ref($_->{$key}) eq "HASH" } $right, $left;
+
+        if ($hr and $hl) {
+            $merged{$key} = $self->_merge($left->{$key}, $right->{$key});
+        } else {
+            $merged{$key} = $right->{$key};
+        }
+    }
+
+    return \%merged;
+}
+
 1;
